Builtin routers
===============

Vumi ships with a small set of generically useful routers:

.. contents:: Vumi routers
    :local:

.. py:module:: vumi.dispatchers


SimpleDispatchRouter
^^^^^^^^^^^^^^^^^^^^

.. autoclass:: SimpleDispatchRouter


TransportToTransportRouter
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: TransportToTransportRouter


ToAddrRouter
^^^^^^^^^^^^

.. autoclass:: ToAddrRouter


FromAddrMultiplexRouter
^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: FromAddrMultiplexRouter


UserGroupingRouter
^^^^^^^^^^^^^^^^^^

.. autoclass:: UserGroupingRouter


ContentKeywordRouter
^^^^^^^^^^^^^^^^^^^^

.. autoclass:: ContentKeywordRouter
